<template>
  <div class="defs">
    <div class="def" :id="slugify(def.term)" v-for="def in definitions.data.map(d=>d.attributes)">
      <div class="anchor">
        <a :href="`#${slugify(def.term)}`" class="term f-copy-h4">
          {{def.term}}
        </a>
      </div>
      <div class="marked shareable f-copy-sans" v-html="$marked(def.text)">
      </div>
    </div>
  </div>
</template>

<script setup>

import slugify from 'slugify'

const { locale, locales } = useI18n()
const localeCode = computed(()=>locales.value.find(l=>l.code == locale.value).ietf)

const {public: {apiUrl}} = useRuntimeConfig()
const {data: definitions} = await useFetch(apiUrl, {
  method: "POST",
  body:{
    query:`{
      definitions(locale: "${localeCode.value}", pagination: {limit: -1}){
        data{
          attributes{
            term
            text
          }
        }
      }
    }`
  },
  transform: r=>r.data.definitions
})

</script>

<style lang="scss" scoped>


.def{
  margin-bottom: 75px;
}

.anchor{
  &::before{
    content: "";
    display: block;
    height: 75px; /* fixed header height*/
    margin-top: -75px;
  }
  a{
    position: relative;
    text-decoration: none;
    &:hover{
      text-decoration: underline;
    }
  }
}

</style>